@@ -2,8 +2,7 @@ import uuid
 
 from django.conf import settings
 from django.contrib import admin, messages
-from django.core.exceptions import ValidationError
-from django.http import HttpResponse, JsonResponse
+from django.http import HttpResponse
 from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth import get_user_model
 from django.template.response import TemplateResponse
@@ -13,7 +12,7 @@ from django.shortcuts import render, redirect, reverse
 
 from .generator.forms import QrGenerateForm
 from .generator.zip import generate_qr_zip
-from .models import ApiHit, Department, LinkUrl, QRCode
+from .models import ApiHit, Department, LinkUrl, QRCode, ApiCall, Header
 from .serializers import ApiHitSerializer
 from rest_framework.renderers import JSONRenderer
 
@@ -126,8 +125,16 @@ class QRCodeAdmin(admin.ModelAdmin):
         return TemplateResponse(request, 'qrtoolkit_core/qrcode/scanner.html', context)
 
     def download_codes(self, request):
+        """
+        Downloads specified qr codes in a zip archive. qr code id's are provided by using the 'codes' query parameter
+
+        :type request: django.http.HttpRequest
+        """
         pks = [int(x) for x in request.GET['codes'].split(',')]
-        codes = QRCode.objects.filter(pk__in=pks, department__in=request.user.departments.all()).all()
+        if request.user.is_superuser:
+            codes = QRCode.objects.filter(pk__in=pks).all()
+        else:
+            codes = QRCode.objects.filter(pk__in=pks, department__in=request.user.departments.all()).all()
         if request.method == 'POST':
             form = QrGenerateForm(data=request.POST)
             if form.is_valid():
@@ -161,6 +168,22 @@ class DepartmentAdmin(admin.ModelAdmin):
     pass
 
 
+class HeaderInline(admin.TabularInline):
+    model = Header
+    extra = 1
+
+
+@admin.register(ApiCall)
+class ApiCallAdmin(admin.ModelAdmin):
+    inlines = [HeaderInline]
+
+    def get_field_queryset(self, db, db_field, request):
+        if db_field.name == 'code':
+            if not request.user.is_superuser:
+                return db_field.remote_field.model.objects.filter(department__in=request.user.departments.all())
+        return super(ApiCallAdmin, self).get_field_queryset(db, db_field, request)
+
+
 admin.site.site_header = 'Qr Gent Administration'
 admin.site.site_title = 'Qr Gent admin'
 admin.site.site_url = settings.API_URL
