@@ -4,6 +4,11 @@ from django.conf import settings
 
 
 def create_qr_code(code, form):
+    """
+
+    :type code: qrtoolkit_core.models.QRCode
+    :type form: qrtoolkit_core.generator.forms.QrGenerateForm
+    """
     out = io.BytesIO()
     url = f'{settings.REDIRECT_SERVICE_URL}/{code.short_uuid}/'
     qr = segno.make_qr(url)
